@@ -1,58 +1,58 @@
 from __future__ import annotations
-from typing import List, Dict, Any, Type, Optional, TypeVar, TYPE_CHECKING
+from typing import Any, Optional, TypeVar, cast, TYPE_CHECKING
 from datetime import date
-from jsonclasses import (fields, Types, Config, FieldType, FieldStorage,
-                         collection_argument_type_to_types)
+from jsonclasses import (get_fields, Types, Config, FieldType, FieldStorage,
+                         resolve_types)
 from inflection import underscore, camelize
 from .utils import (ref_field_key, ref_field_keys, ref_db_field_key,
                     ref_db_field_keys)
 from .coder import Coder
 if TYPE_CHECKING:
-    from .mongo_object import MongoObject
-    T = TypeVar('T', bound=MongoObject)
+    from .base_mongo_object import BaseMongoObject
+    T = TypeVar('T', bound=BaseMongoObject)
 
 
 class Decoder(Coder):
 
     def decode_list(self,
-                    value: List[Any],
-                    cls: Type[T],
-                    types: Types) -> Optional[List[Any]]:
+                    value: list[Any],
+                    cls: type[T],
+                    types: Types) -> Optional[list[Any]]:
         if value is None:
             return None
-        if types.field_description.field_storage == FieldStorage.FOREIGN_KEY:
+        if types.fdesc.field_storage == FieldStorage.FOREIGN_KEY:
             return None
-        elif types.field_description.field_storage == FieldStorage.LOCAL_KEY:
+        elif types.fdesc.field_storage == FieldStorage.LOCAL_KEY:
             return [str(item) for item in value]
         else:
-            item_types = types.field_description.list_item_types
+            item_types = resolve_types(types.fdesc.raw_item_types)
             return ([self.decode_item(value=item, cls=cls, types=item_types)
                     for item in value])
 
     def decode_dict(self,
-                    value: Dict[str, Any],
-                    cls: Type[T],
-                    types: Types) -> Optional[Dict[str, Any]]:
+                    value: dict[str, Any],
+                    cls: type[T],
+                    types: Types) -> Optional[dict[str, Any]]:
         if value is None:
             return None
         config: Config = cls.config
-        if types.field_description.field_storage == FieldStorage.FOREIGN_KEY:
+        if types.fdesc.field_storage == FieldStorage.FOREIGN_KEY:
             return None
-        if types.field_description.field_storage == FieldStorage.LOCAL_KEY:
+        if types.fdesc.field_storage == FieldStorage.LOCAL_KEY:
             return ({underscore(k) if config.camelize_db_keys else k: str(v)
                     for k, v in value.items()})
         else:
-            item_types = types.field_description.dict_item_types
+            item_types = resolve_types(types.fdesc.raw_item_types)
             return ({underscore(k) if config.camelize_db_keys else k:
                     self.decode_item(value=v, cls=cls, types=item_types)
                     for k, v in value.items()})
 
     def decode_shape(self,
-                     value: Dict[str, Any],
-                     cls: Type[T],
-                     types: Types) -> Dict[str, Any]:
+                     value: dict[str, Any],
+                     cls: type[T],
+                     types: Types) -> dict[str, Any]:
         config: Config = cls.config
-        shape_types = types.field_description.shape_types
+        shape_types = cast(dict[str, Any], types.fdesc.shape_types)
         retval = {}
         for k, item_types in shape_types.items():
             retval[k] = self.decode_item(
@@ -63,42 +63,44 @@ class Decoder(Coder):
         return retval
 
     def decode_instance(self,
-                        value: Dict[str, Any],
-                        cls: Type[T],
+                        value: dict[str, Any],
+                        cls: type[T],
                         types: Types) -> Any:
-        if types.field_description.field_storage == FieldStorage.FOREIGN_KEY:
+        from .base_mongo_object import BaseMongoObject
+        if types.fdesc.field_storage == FieldStorage.FOREIGN_KEY:
             return None
-        elif types.field_description.field_storage == FieldStorage.LOCAL_KEY:
+        elif types.fdesc.field_storage == FieldStorage.LOCAL_KEY:
             return str(value)
         else:
             return self.decode_root(
                 root=value,
-                cls=collection_argument_type_to_types(
-                    types.field_description.instance_types, graph_sibling=cls
-                ).field_description.instance_types
+                cls=cast(type[BaseMongoObject], resolve_types(
+                    types.fdesc.instance_types,
+                    graph_sibling=cls
+                ).fdesc.instance_types)
             )
 
-    def decode_item(self, value: Any, cls: Type[T], types: Types) -> Any:
+    def decode_item(self, value: Any, cls: type[T], types: Types) -> Any:
         if value is None:
             return value
-        if types.field_description.field_type == FieldType.DATE:
+        if types.fdesc.field_type == FieldType.DATE:
             return date.fromisoformat(value.isoformat()[:10])
-        elif types.field_description.field_type == FieldType.LIST:
+        elif types.fdesc.field_type == FieldType.LIST:
             return self.decode_list(value=value, cls=cls, types=types)
-        elif types.field_description.field_type == FieldType.DICT:
+        elif types.fdesc.field_type == FieldType.DICT:
             return self.decode_dict(value=value, cls=cls, types=types)
-        elif types.field_description.field_type == FieldType.SHAPE:
+        elif types.fdesc.field_type == FieldType.SHAPE:
             return self.decode_shape(value=value, cls=cls, types=types)
-        elif types.field_description.field_type == FieldType.INSTANCE:
+        elif types.fdesc.field_type == FieldType.INSTANCE:
             return self.decode_instance(value=value, cls=cls, types=types)
         else:
             return value
 
     def decode_root(self,
-                    root: Dict[str, Any],
-                    cls: Type[T]) -> T:
+                    root: dict[str, Any],
+                    cls: type[T]) -> T:
         dest = cls()
-        for field in fields(cls):
+        for field in get_fields(cls):
             if self.is_id_field(field):
                 setattr(dest, 'id', str(root.get('_id')))
             elif self.is_foreign_key_storage(field):
@@ -135,4 +137,7 @@ class Decoder(Coder):
                         cls=cls
                     )
                 )
+        setattr(dest, '_is_new', False)
+        setattr(dest, '_is_modified', False)
+        setattr(dest, '_modified_fields', set())
         return dest
